@@ -1,4 +1,5 @@
 /* -*- Mode: C; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
+#if defined WIN32 || defined __APPLE__
 
 #include "common.h"
 #include <libwebsockets.h>
@@ -520,6 +521,10 @@ handle_file_lock (json_t *content)
             return -1;
         }
         lock_user = json_string_value (member);
+        // don't need to lock file when file has beed locked.\n
+        if (seaf_filelock_manager_get_lock_status (seaf->filelock_mgr, repo_id, path) != FILE_NOT_LOCKED) {
+            return 0;
+        }
 
         FileLockType type = LOCKED_OTHERS;
         if (g_strcmp0 (lock_user, repo->email) == 0)
@@ -527,6 +532,9 @@ handle_file_lock (json_t *content)
 
         seaf_filelock_manager_lock_file (seaf->filelock_mgr, repo_id, path, type);
     } else if (g_strcmp0 (change_event, "unlocked") == 0) {
+        if (seaf_filelock_manager_get_lock_status (seaf->filelock_mgr, repo_id, path) == FILE_NOT_LOCKED) {
+            return 0;
+        }
         seaf_filelock_manager_mark_file_unlocked (seaf->filelock_mgr, repo_id, path);
     }
 
@@ -825,13 +833,6 @@ notification_worker (void *vdata)
         g_usleep (RECONNECT_INTERVAL * G_USEC_PER_SEC);
         n = 0;
         server->status = STATUS_DISCONNECTED;
-
-        lws_context_destroy(server->context);
-        server->context = NULL;
-        server->context = lws_context_new (server->use_ssl);
-        if (!server->context)
-            break;
-        i->context = server->context;
     }
 
     seaf_message ("Notification worker for server %s exiting.\n", server->server_url);
@@ -973,3 +974,5 @@ out:
     notif_server_unref (server);
     return subscribed;
 }
+
+#endif
